moments: Second moment tensor

View source: R/moments.R

momentsR Documentation

Second moment tensor

Description

Computes the second moment tensor of a set of point masses in arbitrary dimensions,

\mathbf{M} = \sum_i m_i\,\mathbf{x}_i\mathbf{x}_i^\mathrm{T}.

Usage

moments(x, m = 1)

Arguments

x

Numeric vector or matrix. If a matrix is supplied, each row is interpreted as a point.

m

Numeric scalar or vector of point masses. If a scalar is supplied, the same mass is assigned to every point.

Value

A symmetric d\times d matrix containing the second moment tensor, where d is the dimension of the points.

See Also

quadrupole, inertia


cooltools documentation built on Sept. 11, 2026, 5:06 p.m.