View source: R/scalarproduct.R
| scalarproduct | R Documentation |
Computes the scalar (dot) product of vectors. The inputs may be individual vectors or matrices whose rows represent vectors.
scalarproduct(x, y)
x, y |
Numeric vectors or matrices. If a matrix is supplied, each row is interpreted as a vector. |
Returns either a scalar (vector-vector case) or a vector containing the row-wise scalar products.
scalarproduct, vectornorm,
unitvector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.