| distradius | R Documentation |
Computes a characteristic radius of a set of points about a centre.
distradius(x, m = NULL, x0 = NULL, type = c("max", "mean", "median"))
x |
Numeric vector or matrix. If a matrix is supplied, each row is interpreted as a point. |
m |
Optional numeric vector of point masses or weights. If |
x0 |
Optional numeric vector specifying the centre. If |
type |
Character string specifying the radius definition. One of
|
A scalar radius.
vectornorm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.