| moments | R Documentation |
Computes the second moment tensor of a set of point masses in arbitrary dimensions,
\mathbf{M}
=
\sum_i m_i\,\mathbf{x}_i\mathbf{x}_i^\mathrm{T}.
moments(x, m = 1)
x |
Numeric vector or matrix. If a matrix is supplied, each row is interpreted as a point. |
m |
Numeric scalar or vector of point masses. If a scalar is supplied, the same mass is assigned to every point. |
A symmetric d\times d matrix containing the second moment tensor,
where d is the dimension of the points.
quadrupole, inertia
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.