| quadrupole | R Documentation |
Computes the trace-free mass quadrupole tensor of a set of point masses in arbitrary dimensions,
\mathbf{Q}
=
\sum_i m_i
\left(
d\,\mathbf{x}_i\mathbf{x}_i^\mathrm{T}
-
|\mathbf{x}_i|^2\mathbf{I}
\right),
where d is the dimensionality of the points and \mathbf{I} is
the d\times d identity matrix.
quadrupole(x, m = 1)
x |
Numeric vector or matrix. If a matrix is supplied, each row is interpreted as a point. |
m |
Numeric scalar or vector of point masses. If a scalar is supplied, the same mass is assigned to every point. |
A symmetric d\times d matrix containing the trace-free quadrupole
tensor.
moments, inertia
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.