| unitvector | R Documentation |
Computes unit vectors from one or more vectors.
unitvector(x)
x |
Numeric vector or matrix. If a matrix is supplied, each row is interpreted as a vector. |
An object of the same type and dimensions as x, with each vector
normalized to unit length. Zero vectors are returned unchanged.
vectornorm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.